@@ -67,4 +67,14 @@ class NestedMountedVolumeSerializer(WritableNestedSerializer):
 
     class Meta:
         model = MountedVolume
-        fields = ["id", "url", "display", "mount_point"]
\ No newline at end of file
+        fields = ["id", "url", "display", "mount_point"]
+
+
+class NestedVolumeGroupSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:volumegroup-detail"
+    )
+
+    class Meta:
+        model = MountedVolume
+        fields = ["id", "url", "display", "vg_name"]
