@@ -5,11 +5,14 @@ from rest_framework.routers import APIRootView
 from netbox.api.viewsets import NetBoxModelViewSet
 from netbox_storage.api.serializers import (
     DriveSerializer,
-    FilesystemSerializer, PartitionSerializer, MountedVolumeSerializer, LinuxDeviceSerializer
+    FilesystemSerializer, PartitionSerializer, MountedVolumeSerializer, LinuxDeviceSerializer, LogicalVolumeSerializer,
+    PhysicalVolumeSerializer, VolumeGroupSerializer
 )
 from netbox_storage.filters import DriveFilter, FilesystemFilter, \
-    PartitionFilter, MountedVolumeFilter, LinuxDeviceFilter
-from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, LinuxDevice
+    PartitionFilter, MountedVolumeFilter, LinuxDeviceFilter, PhysicalVolumeFilter, VolumeGroupFilter, \
+    LogicalVolumeFilter
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, LinuxDevice, LogicalVolume, \
+    PhysicalVolume, VolumeGroup
 
 
 class NetboxStorageRootView(APIRootView):
@@ -79,3 +82,39 @@ class LinuxDeviceViewSet(NetBoxModelViewSet):
         linuxdevice = LinuxDevice.objects.filter(linuxdevice__id=pk)
         serializer = LinuxDeviceSerializer(linuxdevice, many=True, context={"request": request})
         return Response(serializer.data)
+
+
+class LogicalVolumeViewSet(NetBoxModelViewSet):
+    queryset = LogicalVolume.objects.all()
+    serializer_class = LogicalVolumeSerializer
+    filterset_class = LogicalVolumeFilter
+
+    @action(detail=True, methods=["get"])
+    def logicalvolume(self, request, pk=None):
+        logicalvolume = LogicalVolume.objects.filter(logicalvolume__id=pk)
+        serializer = LogicalVolumeSerializer(logicalvolume, many=True, context={"request": request})
+        return Response(serializer.data)
+
+
+class PhysicalVolumeViewSet(NetBoxModelViewSet):
+    queryset = PhysicalVolume.objects.all()
+    serializer_class = PhysicalVolumeSerializer
+    filterset_class = PhysicalVolumeFilter
+
+    @action(detail=True, methods=["get"])
+    def physicalvolume(self, request, pk=None):
+        physicalvolume = PhysicalVolume.objects.filter(physicalvolume__id=pk)
+        serializer = PhysicalVolumeSerializer(physicalvolume, many=True, context={"request": request})
+        return Response(serializer.data)
+
+
+class VolumeGroupViewSet(NetBoxModelViewSet):
+    queryset = VolumeGroup.objects.all()
+    serializer_class = VolumeGroupSerializer
+    filterset_class = VolumeGroupFilter
+
+    @action(detail=True, methods=["get"])
+    def volumegroup(self, request, pk=None):
+        volumegroup = VolumeGroup.objects.filter(volumegroup__id=pk)
+        serializer = VolumeGroupSerializer(volumegroup, many=True, context={"request": request})
+        return Response(serializer.data)
