@@ -1,7 +1,7 @@
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
-    FloatField, BooleanField
+    FloatField,
 )
 from django.urls import reverse_lazy
 
@@ -18,8 +18,14 @@ from virtualization.models import Cluster, ClusterType, VirtualMachine
 
 
 class LVMTemplateForm(NetBoxModelForm):
-    """Form for creating a new Drive object."""
-    # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+    platform = DynamicModelChoiceField(
+        queryset=Platform.objects.all(),
+        help_text="Mapping between drive and platform  e.g. Rocky Linux 9",
+    )
+    drive = DynamicModelChoiceField(
+        queryset=Drive.objects.all(),
+        help_text="The Cluster Type of the drive",
+    )
     lv_name = CharField(
         label="LV Name",
         help_text="Logical Volume Name e.g. lv_docker",
@@ -33,8 +39,8 @@ class LVMTemplateForm(NetBoxModelForm):
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
-    mount_point = CharField(
-        label="mount_point",
+    mountpoint = CharField(
+        label="Mountpoint",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
     fs_type = DynamicModelChoiceField(
@@ -50,34 +56,6 @@ class LVMTemplateForm(NetBoxModelForm):
         label="FS Options",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
-    cluster_type = DynamicModelChoiceField(
-        queryset=ClusterType.objects.all(),
-        help_text="The Cluster Type of the drive",
-    )
-    cluster = DynamicModelChoiceField(
-        queryset=Cluster.objects.all(),
-        query_params={
-            'type_id': '$cluster_type'  # ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
-        },
-        help_text="The Storage Cluster of the drive",
-    )
-    platform = DynamicModelChoiceField(
-        queryset=Platform.objects.all(),
-        help_text="Mapping between drive and platform  e.g. Rocky Linux 9",
-    )
-    drive = DynamicModelChoiceField(
-        queryset=Drive.objects.all(),
-        help_text="The Cluster Type of the drive",
-    )
-    description = CharField(
-        required=False,
-        label="Description",
-        help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
-    )
-    checkbox_partition = BooleanField(
-        label="Create extra partition",
-        help_text="Create an extra partition e.g. /dev/sdb1",
-    )
 
     fieldsets = (
         (
@@ -85,7 +63,6 @@ class LVMTemplateForm(NetBoxModelForm):
             (
                 "drive",
                 "platform",
-                "checkbox_partition"
             ),
         ),
         (
@@ -94,10 +71,9 @@ class LVMTemplateForm(NetBoxModelForm):
                 "lv_name",
                 "vg_name",
                 "size",
-                "mount_point",
+                "mountpoint",
                 "fs_type",
-                "fs_options",
-                "description",
+                "fs_options"
             ),
         ),
     )
@@ -109,37 +85,16 @@ class LVMTemplateForm(NetBoxModelForm):
         ]
 
     def save(self, *args, **kwargs):
-        print(f"drive: {self.cleaned_data['drive']}")
-        print(f"ID OF drive: {self.cleaned_data['drive'].id}")
-        print(f"ID OF drive: {self.cleaned_data['drive'].cluster}")
-        new_partition_count = Partition.objects.filter(drive_id=self.cleaned_data['drive'].id).count() + 1
-        device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
-        print(f"Partition Count: {new_partition_count}")
-        print(f"Device Name: {device_name_prefix}")
-        device_name = device_name_prefix + str(new_partition_count)
-
-        mounted_volume = MountedVolume.objects.create(mount_point=self.cleaned_data['mount_point'],
-                                                      fs_type=self.cleaned_data['fs_type'],
-                                                      options=self.cleaned_data['fs_options'])
-
-        linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
-        partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device, size=self.cleaned_data['drive'], type='Linux LVM')
-
-        volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
-        PhysicalVolume.objects.create(device=linux_device, vg=volume_group)
-
-        print(f"Checkbox Partition: {self.cleaned_data['checkbox_partition']}")
-        print(f"{self.cleaned_data['lv_name']}")
-        print(f"{self.cleaned_data['vg_name']}")
-        print(f"{self.cleaned_data['size']}")
-        print(f"{self.cleaned_data['mount_point']}")
-        print(f"{self.cleaned_data['fs_type']}")
-
-        linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home', type='ext4')
-
+        print(f"Drive: {self.cleaned_data['drive']}")
+        print(f"Platform: {self.cleaned_data['platform']}")
+        print(f"LV Name: {self.cleaned_data['lv_name']}")
+        print(f"VG Name: {self.cleaned_data['vg_name']}")
+        print(f"Size: {self.cleaned_data['size']}")
+        print(f"Mountpoint: {self.cleaned_data['mountpoint']}")
+        print(f"Filesystem: {self.cleaned_data['fs_type']}")
+        print(f"Filesystem Options: {self.cleaned_data['fs_options']}")
         self.instance.vg = self.cleaned_data['drive']
-        self.instance.size = linux_device
-        self.instance.device = linux_device_mapper
+        self.instance.size = self.cleaned_data['size']
         logical_volume = super().save(*args, **kwargs)
 
         return logical_volume
